==> OpenCL-0.8.3.tgz: OpenCL-0.8.3/include/rw.h <==
/*************************************************
* Rabin-Williams Header File                     *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_RW_H__
#define OPENCL_RW_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/exp.h>

namespace OpenCL {

class RW_PublicKey : public PK_Verifying_with_MR_Key
   {
   public:
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (n.bits() - 1); }

      bool check_params() const;
      BigInt get_n() const { return n; }
      BigInt get_e() const { return e; }

      RW_PublicKey(const BigInt&, const BigInt&);
   protected:
      RW_PublicKey() { }
      BigInt public_op(const BigInt&) const;
      BigInt n, e;
      FixedExponent_Exp powermod_e_n;
      mutable BigInt temp;
   };

class RW_PrivateKey : public RW_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      BigInt get_p() const { return p; }
      BigInt get_q() const { return q; }
      BigInt get_d() const { return d; }

      RW_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                    const BigInt& = 0, const BigInt& = 0);
      RW_PrivateKey(u32bit, const BigInt& = 2);
   private:
      BigInt private_op(const BigInt&) const;
      BigInt if_key_private_op(const BigInt&) const;
      void precompute();
      BigInt d, p, q, d1, d2, c;
      FixedExponent_Exp powermod_d1_p, powermod_d2_q;
      mutable BigInt j1, j2, h;
   };

}

#endif

==> OpenCL-0.8.4.tgz: OpenCL-0.8.4/include/rw.h <==
/*************************************************
* Rabin-Williams Header File                     *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_RW_H__
#define OPENCL_RW_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/mod_exp.h>

namespace OpenCL {

/*************************************************
* Rabin-Williams Public Key                      *
*************************************************/
class RW_PublicKey : public PK_Verifying_with_MR_Key
   {
   public:
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (n.bits() - 1); }

      bool check_params() const;
      const BigInt& get_n() const { return n; }
      const BigInt& get_e() const { return e; }

      RW_PublicKey(const BigInt&, const BigInt&);
   protected:
      RW_PublicKey() { }
      BigInt public_op(const BigInt&) const;
      BigInt n, e;
      FixedExponent_Exp powermod_e_n;
      mutable BigInt temp;
   };

/*************************************************
* Rabin-Williams Private Key                     *
*************************************************/
class RW_PrivateKey : public RW_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      const BigInt& get_p() const { return p; }
      const BigInt& get_q() const { return q; }
      const BigInt& get_d() const { return d; }

      RW_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                    const BigInt& = 0, const BigInt& = 0);
      RW_PrivateKey(u32bit, const BigInt& = 2);
   private:
      BigInt private_op(const BigInt&) const;
      BigInt if_key_private_op(const BigInt&) const;
      void precompute();
      BigInt d, p, q, d1, d2, c;
      FixedExponent_Exp powermod_d1_p, powermod_d2_q;
   };

}

#endif
